@@ -6,7 +6,7 @@ import functools
 import logging
 import weakref
 
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 
 
 def _logger():
@@ -748,7 +748,7 @@ class TextHelper(object):
             pos = cursor_or_block.position() - b.position()
             layout = b.layout()
         if layout is not None:
-            additional_formats = layout.additionalFormats()
+            additional_formats = layout.formats()
             sh = self._editor.syntax_highlighter
             if sh:
                 ref_formats = sh.color_scheme.formats
