@@ -5,7 +5,7 @@ Contains a base class for a calltips mode.
 import logging
 from pyqode.core.api import Mode, TextHelper
 from pyqode.core.api.panel import Panel
-from pyqode.qt import QtCore, QtWidgets
+from qtpy import QtCore, QtWidgets
 
 MAX_CALLTIP_WIDTH = 80
 
@@ -156,4 +156,4 @@ class CalltipsMode(Mode, QtCore.QObject):
             )
         )
         position = self.editor.mapToGlobal(position)
-        QtWidgets.QToolTip.showText(position, calltip, self.editor)
+        QtWidgets.QToolTip.showText(position, calltip, self.editor)
\ No newline at end of file
