@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 import os
 from pyqode.core import api, icons
-from pyqode.qt.QtCore import Qt
-from pyqode.qt.QtWidgets import QAction
+from qtpy.QtCore import Qt
+from qtpy.QtWidgets import QAction
 
 
 class CommentsMode(api.Mode):
@@ -135,4 +135,4 @@ class CommentsMode(api.Mode):
             cursor.movePosition(cursor.PreviousBlock, cursor.KeepAnchor)
             cursor.movePosition(cursor.EndOfBlock, cursor.KeepAnchor)
         cursor.endEditBlock()
-        self.editor.setTextCursor(cursor)
+        self.editor.setTextCursor(cursor)
\ No newline at end of file
