@@ -3,7 +3,7 @@
 This module contains the ZoomMode which lets you zoom in and out the editor.
 """
 from pyqode.core.api.mode import Mode
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 
 
 class ZoomMode(Mode):
@@ -79,7 +79,7 @@ class ZoomMode(Mode):
         except AttributeError:
             # PyQt4/PySide
             delta = event.delta()
-        if int(event.modifiers()) & QtCore.Qt.ControlModifier > 0:
+        if event.modifiers() & QtCore.Qt.ControlModifier:
             if delta < self.prev_delta:
                 self.editor.zoom_out()
                 event.accept()
