@@ -4,7 +4,7 @@ This module contains the GlobalCheckerPanel.
 """
 from pyqode.core import modes
 from pyqode.core.api import Panel, TextHelper
-from pyqode.qt import QtCore, QtGui
+from qtpy import QtCore, QtGui
 
 
 class GlobalCheckerPanel(Panel):
@@ -104,4 +104,4 @@ class GlobalCheckerPanel(Panel):
         # Moves the editor text cursor to the clicked line.
         height = event.pos().y()
         line = height // self.get_marker_height()
-        TextHelper(self.editor).goto_line(line)
+        TextHelper(self.editor).goto_line(line)
\ No newline at end of file
